@@ -69,7 +69,7 @@ class Dominio_class(Thread):
         self.iTimpMilAnim = 0.02
         self.tarjLoPosX = 747
         self.tarjLoTope= self.tarjLoPosX
-        self.tarjLoIncr = 10
+        self.tarjLoIncr = 30
         
     # Reinicia el juego
     def __PararJuego(self):
@@ -162,8 +162,7 @@ class Dominio_class(Thread):
     
     #Reproduce un sonido
     def reproducirSonido(self, inFile):
-        pygame.mixer.music.load(inFile)
-        pygame.mixer.music.play()
+        pygame.mixer.Sound(inFile).play()
     
     # Asigna un numero al boton: 1 - Amarillo, 2 - Azul, 3 - Rojo, 4 - Verde, 5 - Start, 6 - Desplegar logros
     def averiguarNumBoton(self, inBoton):
